@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2020-2022 Salvador E. Tropea
-# Copyright (c) 2020-2022 Instituto Nacional de Tecnologïa Industrial
+# Copyright (c) 2020-2023 Salvador E. Tropea
+# Copyright (c) 2020-2023 Instituto Nacional de Tecnologïa Industrial
 # License: Apache 2.0
 # Project: KiAuto (formerly kicad-automation-scripts)
 import configparser
@@ -36,6 +36,8 @@ MISSING_TOOL = 15
 KICAD_DIED = 16
 READ_ONLY_PROBLEM = 17
 WONT_OVERWRITE = 18
+KICAD_CLI_ERROR = 19
+CORRUPTED_CONFIG = 20
 # Wait 60 s to pcbnew/eeschema window to be present
 WAIT_START = 60
 # Name for testing versions
@@ -44,8 +46,14 @@ NIGHTLY = 'nightly'
 TIME_OUT_MULT = 1.0
 
 KICAD_VERSION_5_99 = 5099000
+KICAD_VERSION_6_99 = 6099000
+KICAD_VERSION_7_99 = 7099000
+KICAD_VERSION_7_0_3 = 7000003
+KICAD_VERSION_7_0_8 = 7000008
 KICAD_SHARE = '/usr/share/kicad/'
 KICAD_NIGHTLY_SHARE = '/usr/share/kicad-nightly/'
+RULES_KEY = 'Ctrl+Shift+A'
+# RULES_KEY = 'Alt+I'
 
 
 @contextmanager
@@ -61,6 +69,7 @@ def hide_stderr():
 
 class Config(object):
     def __init__(self, logger, input_file=None, args=None, is_pcbnew=False):
+        logger.debug(f'KiAuto v{__version__}')
         self.export_format = 'pdf'
         self.is_pcbnew = is_pcbnew
         if input_file:
@@ -111,15 +120,18 @@ class Config(object):
         self.eeschema = 'eeschema'
         self.pcbnew = 'pcbnew'
         self.kicad2step = 'kicad2step'
+        self.kicad_cli = 'kicad-cli'
         self.kicad_conf_dir = 'kicad'
         ng_ver = os.environ.get('KIAUS_USE_NIGHTLY')
         if ng_ver:
             self.eeschema += '-'+NIGHTLY
             self.pcbnew += '-'+NIGHTLY
             self.kicad2step += '-'+NIGHTLY
+            self.kicad_cli += '-'+NIGHTLY
             self.kicad_conf_dir += os.path.join(NIGHTLY, ng_ver)
             # Path to the Python module
             path.insert(0, '/usr/lib/kicad-nightly/lib/python3/dist-packages')
+            os.environ['KICAD_PATH'] = '/usr/share/kicad-nightly'
         # Detect KiCad version
         try:
             import pcbnew
@@ -146,6 +158,15 @@ class Config(object):
         logger.debug('Detected KiCad v{}.{}.{} ({} {})'.format(self.kicad_version_major, self.kicad_version_minor,
                      self.kicad_version_patch, kicad_version, self.kicad_version))
         self.ki5 = self.kicad_version < KICAD_VERSION_5_99
+        self.ki6 = self.kicad_version >= KICAD_VERSION_5_99
+        self.ki7 = self.kicad_version >= KICAD_VERSION_6_99
+        self.ki8 = self.kicad_version >= KICAD_VERSION_7_99
+        if self.ki7:
+            # Now part of the kicad-cli tool
+            self.kicad2step = self.kicad_cli
+            self.drc_dialog_name = 'Design Rules Checker'
+        else:
+            self.drc_dialog_name = 'DRC Control'
         # Config file names
         if not self.ki5:
             self.kicad_conf_path = pcbnew.GetSettingsManager().GetUserSettingsPath()
@@ -169,6 +190,7 @@ class Config(object):
         else:
             self.conf_kicad_json = False
         # Read the environment redefinitions used by KiCad
+        self.env = {}
         if os.path.isfile(self.conf_kicad):
             self.load_kicad_environment(logger)
             if 'KICAD_CONFIG_HOME' in self.env and self.ki5:
@@ -208,6 +230,29 @@ class Config(object):
         # - hotkeys
         self.conf_hotkeys = os.path.join(self.kicad_conf_path, 'user.hotkeys')
         self.conf_hotkeys_bkp = None
+        # share path
+        kpath = os.environ.get('KICAD_PATH')
+        if kpath is None and self.env:
+            kpath = self.env.get('KICAD_PATH')
+        if kpath is None:
+            if os.path.isdir(KICAD_SHARE):
+                kpath = KICAD_SHARE
+            elif os.path.isdir(KICAD_NIGHTLY_SHARE):
+                kpath = KICAD_NIGHTLY_SHARE
+        if kpath is None:
+            logger.warning('Missing KiCad share dir')
+        else:
+            logger.debug('KiCad share dir: '+kpath)
+            vname = 'KICAD'+str(self.kicad_version_major)+'_FOOTPRINT_DIR'
+            # KiCad 7.0.0 rc2 workaround (also 7.0.1 and 7.99 april 2023)
+            # KiCad bug: https://gitlab.com/kicad/code/kicad/-/issues/13815
+            if vname not in os.environ:
+                # Footprint dir not defined, and needed for DRC
+                if self.env and vname in self.env:
+                    os.environ[vname] = self.env[vname]
+                else:
+                    os.environ[vname] = os.path.join(kpath, 'footprints')
+                logger.debug('Defining {} = {}'.format(vname, os.environ[vname]))
         # - sym-lib-table
         self.user_sym_lib_table = os.path.join(self.kicad_conf_path, 'sym-lib-table')
         self.user_fp_lib_table = os.path.join(self.kicad_conf_path, 'fp-lib-table')
@@ -217,12 +262,18 @@ class Config(object):
             # 20200912: sym-lib-table is missing
             self.sys_sym_lib_table.insert(0, KICAD_NIGHTLY_SHARE+'template/sym-lib-table')
             self.sys_fp_lib_table.insert(0, KICAD_NIGHTLY_SHARE+'template/fp-lib-table')
+        if kpath is not None:
+            self.sys_sym_lib_table.insert(0, os.path.join(kpath, 'template/sym-lib-table'))
+            self.sys_fp_lib_table.insert(0, os.path.join(kpath, 'template/fp-lib-table'))
         # Some details about the UI
         if not self.ki5:
             # KiCad 5.99.0
             # self.ee_window_title = r'\[.*\] — Eeschema$'  # "PROJECT [HIERARCHY_PATH] - Eeschema"
-            # KiCad 6.0.0 rc1
-            self.ee_window_title = r'\[.*\] — Schematic Editor$'  # "PROJECT [HIERARCHY_PATH] - Schematic Editor"
+            if self.ki7:
+                self.ee_window_title = r'.* — Schematic Editor$'  # "SHEET [HIERARCHY_PATH]? - Schematic Editor"
+            else:
+                # KiCad 6.x
+                self.ee_window_title = r'\[.*\] — Schematic Editor$'  # "PROJECT [HIERARCHY_PATH] - Schematic Editor"
             self.pn_window_title = r'.* — PCB Editor$'  # "PROJECT - PCB Editor"
             self.pn_simple_window_title = 'PCB Editor'
             kind = 'PCB' if self.is_pcbnew else 'Schematic'
@@ -241,7 +292,7 @@ class Config(object):
     def load_kicad_environment(self, logger):
         self.env = {}
         if self.conf_kicad_json:
-            env = self.get_config_vars_json(self.conf_kicad)
+            env = self.get_config_vars_json(self.conf_kicad, logger)
             if env:
                 self.env = env
         else:
@@ -252,9 +303,14 @@ class Config(object):
         logger.debug('KiCad environment: '+str(self.env))
 
     @staticmethod
-    def get_config_vars_json(file):
+    def get_config_vars_json(file, logger):
         with open(file, "rt") as f:
-            data = json.load(f)
+            raw_data = f.read()
+            try:
+                data = json.loads(raw_data)
+            except json.decoder.JSONDecodeError:
+                logger.error(f"Corrupted KiCad config file `{file}`:\n{raw_data}")
+                exit(CORRUPTED_CONFIG)
         if 'environment' in data and 'vars' in data['environment']:
             return data['environment']['vars']
         return None
@@ -292,10 +348,10 @@ def get_en_locale(logger):
 
 
 __author__ = 'Salvador E. Tropea'
-__copyright__ = 'Copyright 2018-2023, INTI/Productize SPRL'
+__copyright__ = 'Copyright 2018-2024, INTI/Productize SPRL'
 __credits__ = ['Salvador E. Tropea', 'Seppe Stas', 'Jesse Vincent', 'Scott Bezek']
 __license__ = 'Apache 2.0'
 __email__ = 'stropea@inti.gob.ar'
 __status__ = 'stable'
 __url__ = 'https://github.com/INTI-CMNB/KiAuto/'
-__version__ = '2.1.1'
+__version__ = '2.3.3'
